#
# spec file for package python-pycodestyle
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pycodestyle
Version:        2.11.0
Release:        1.1
Summary:        Python style guide checker
License:        MIT
Group:          Development/Languages/Python
URL:            https://pycodestyle.readthedocs.io/
Source:         https://github.com/PyCQA/pycodestyle/archive/refs/tags/%{version}.tar.gz#/pycodestyle-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun):update-alternatives
Provides:       python-pep8 = %{version}
Obsoletes:      python-pep8 < %{version}
BuildArch:      noarch
%python_subpackages

%description
pycodestyle is a tool to check your Python code against some of the style
conventions in `PEP 8`.

This package used to be called ``pep8`` but was renamed to ``pycodestyle``
to reduce confusion.

%prep
%setup -q -n pycodestyle-%{version}
%autopatch -p1
sed -ri '1s/^#!.*//' pycodestyle.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/pycodestyle
%python_expand %fdupes %{buildroot}/%{$python_sitelib}

%post
%python_install_alternative pycodestyle

%postun
%python_uninstall_alternative pycodestyle

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%python_alternative %{_bindir}/pycodestyle
%{python_sitelib}/pycodestyle.py*
%pycache_only %{python_sitelib}/__pycache__/pycodestyle.*.py*
%{python_sitelib}/pycodestyle-%{version}*-info

%changelog
* Tue Aug  8 2023 ecsos <ecsos@opensuse.org>
- %%{?sle15_python_module_pythons} must at beginning of spec to work.
* Thu Aug  3 2023 Martin Schreiner <martin.schreiner@suse.com>
- Update to 2.11.0
  * Drop EOL python 3.6 / 3.7.
  * Add support for python 3.12.
  * E721: adjust handling of type comparison.
    Allowed forms are now isinstance(x, t) or type(x) is t.
  * Remove handling of python 2 <> operator.
  * W606: removed. async / await are always keywords.
  * Internal: move tests to pytest.
  * Remove handling of python 2 ur'' strings.
- Remove testsuite_fixes.patch as it's no longer required
- Replaced spec file "Source" to pull from GitHub due to this issue:
  https://github.com/PyCQA/pycodestyle/issues/1183
- Apply spec-cleaner to spec file.
* Tue Jul 18 2023 Ana Guerrero <ana.guerrero@suse.com>
- Add patch to fix testsuite with python 3.11.4 and 3.12
  testsuite_fixes.patch
* Tue May  9 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Fri Jan 13 2023 Johannes Kastl <kastl@b1-systems.de>
- cleanup spec, trim %%files section and fix %%python_clone command
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2.10.0  (bsc#1206225)
  * Changes:
  E231: allow trailing comma inside 1-tuples in []. PR #1108.
  W601, W602, W603, W604: removed (no longer relevant in python 3). PR #1111.
  E741: also apply to lambdas. PR #1106.
  E741: fix false positive for comparison operators. PR #1118.
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- update to 2.9.1:
  * E275: fix false positive for yield expressions.
  * E221, E222, E223, E224: add support for := operator. PR #1032.
  * Drop python 2.7 / 3.5.
  * E262: consider non-breaking spaces (\xa0) as whitespace. PR #1035.
  * Improve performance of _is_binary_operator. PR #1052.
  * E275: requires whitespace around keywords. PR #1063.
  * Add support for python 3.11. PR #1070.
* Thu Nov  4 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 2.8.0
  * fix false negative with multiple comparisons
  * fix false positives with ``match``
  * improve performance of bare except check
  * Backport tokenize performance improvement from python 3.10
  * fix for lambdas containing positional-only args
  * Remove ``indent_size_str`` "setting"
  * allow ``__all__`` to be typed
  * fix false positives for ``*`` in ``case``
  * detect tabs as whitespace
* Tue Mar 16 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.7.0
  * Fix physical checks (such as W191) at end of file.
  * Add ``--indent-size`` option (defaulting to ``4``).
  * W605: fix escaped crlf false positive on windows.
* Thu May 14 2020 Benjamin Greiner <code@bnavigator.de>
- Update to version 2.6.0
  * E306: fix detection inside ``async def``.
    PR gh#PyCQA/pycodestyle#929.
  * E301: fix regression disallowing decorated one-liners.
    PR gh#PyCQA/pycodestyle#927.
  * E714: fix false positive with chained ``is not``.
    PR gh#PyCQA/pycodestyle#931.
- Update to version 2.6.0a1
  New checks:
  * E225: require whitespace around ``and`` ``in`` ``is`` and ``or``.
    PR gh#PyCQA/pycodestyle#847.
  Changes:
  * E117: fix indentation using tabs by treating as 8-space indents.
    PR gh#PyCQA/pycodestyle#837.
  * E721: fix false positive with names containg ``istype``.
    PR gh#PyCQA/pycodestyle#850.
  * E741: allow ``l`` as a named argument in a function call.
    PR gh#PyCQA/pycodestyle#853.
  * E302: fix false-negative with decorated functions.
    PR gh#PyCQA/pycodestyle#859.
  * W504: ellipsis (``...``) is no longer treated as a binary operator.
    PR gh#PyCQA/pycodestyle#875.
  * E402: allow ``with``, ``if``, ``elif``, ``else`` to guard imports.
    PR gh#PyCQA/pycodestyle#834.
  * Add support for assignment expressions ``:=`` (PEP 572).
    PR gh#PyCQA/pycodestyle#879.
  * Add support for positional-only arguments ``/`` (PEP 570).
    PR gh#PyCQA/pycodestyle#872, gh#PyCQA/pycodestyle#918.
  * Add support for python 3.8.
  * Add support for matrix multiplication operator ``@`` (PEP 465).
    PR gh#PyCQA/pycodestyle#897.
  * Support visual indent for continuation lines for ``with`` / ``assert`` /
    ``raise``.  PR gh#PyCQA/pycodestyle#912.
  * E302: allow two blank lines after a block of one-liners.
    PR gh#PyCQA/pycodestyle#913.
  * E302: allow two-and-fewer newlines at the top of the file.
    PR gh#PyCQA/pycodestyle#919.
- install executable as alternative
* Thu Jan 31 2019 John Vandenberg <jayvdb@gmail.com>
- update to version 2.5.0
  * New checks:
    + E117: Over-indented code blocks
    + W505: Maximum doc-string length only when configured with --max-doc-length
  * Changes:
    + Remove support for EOL Python 2.6 and 3.3. PR #720.
    + Add E117 error for over-indented code blocks.
    + Allow W605 to be silenced by `# noqa` and fix the position reported by W605
    + Allow users to omit blank lines around one-liner definitions of classes and
    functions
    + Include the function return annotation (``->``) as requiring surrounding
    whitespace only on Python 3
    + Verify that only names can follow ``await``. Previously we allowed numbers
    and strings.
    + Add support for Python 3.7
    + Fix detection of annotated argument defaults for E252
    + Correct the position reported by W504
- Removed comp_w_changes_tokenize.patch as it was merged into version 2.5.0
* Tue Oct  2 2018 Matěj Cepl <mcepl@suse.com>
- Add comp_w_changes_tokenize.patch to make tests more stable
  (gh#pycqa/pycodestyle#786)
* Wed Aug  8 2018 tchvatal@suse.com
- Really run tests
- Drop devel dependency
- Fix provides/obsoletes for pep8
* Wed Apr 11 2018 arun@gmx.de
- specfile:
  * update copyright year
  * add README and LICENSE
- update to version 2.4.0:
  * New checks:
    + Add W504 warning for checking that a break doesn’t happen after
    a binary operator. This check is ignored by default. PR #502.
    + Add W605 warning for invalid escape sequences in string
    literals. PR #676.
    + Add W606 warning for ‘async’ and ‘await’ reserved keywords being
    introduced in Python 3.7. PR #684.
    + Add E252 error for missing whitespace around equal sign in type
    annotated function arguments with defaults values. PR #717.
  * Changes:
    + An internal bisect search has replaced a linear search in order
    to improve efficiency. PR #648.
    + pycodestyle now uses PyPI trove classifiers in order to document
    supported python versions on PyPI. PR #654.
    + ‘setup.cfg’ ‘[wheel]’ section has been renamed to
    ‘[bdist_wheel]’, as the former is legacy. PR #653.
    + pycodestyle now handles very long lines much more efficiently
    for python 3.2+. Fixes #643. PR #644.
    + You can now write ‘pycodestyle.StyleGuide(verbose=True)’ instead
    of ‘pycodestyle.StyleGuide(verbose=True, paths=[‘-v’])’ in order
    to achieve verbosity. PR #663.
    + The distribution of pycodestyle now includes the license text in
    order to comply with open source licenses which require this. PR
    [#694].
    + ‘maximum_line_length’ now ignores shebang (‘#!’) lines. PR #736.
    + Add configuration option for the allowed number of blank
    lines. It is implemented as a top level dictionary which can be
    easily overwritten. Fixes #732. PR #733.
  * Bugs:
    + Prevent a ‘DeprecationWarning’, and a ‘SyntaxError’ in future
    python, caused by an invalid escape sequence. PR #625.
    + Correctly report E501 when the first line of a docstring is too
    long. Resolves #622. PR #630.
    + Support variable annotation when variable start by a keyword,
    such as class variable type annotations in python 3.6. PR #640.
    + pycodestyle internals have been changed in order to allow
    ‘python3 -m cProfile’ to report correct metrics. PR #647.
    + Fix a spelling mistake in the description of E722. PR #697.
    + ‘pycodestyle –diff’ now does not break if your ‘gitconfig’
    enables ‘mnemonicprefix’. PR #706.
* Sat May  6 2017 toddrme2178@gmail.com
- Don't provide python2-pep8, singlespec packages should use
  correct name.
* Fri Mar 24 2017 jmatejek@suse.com
- update for singlespec
- rename from pep8 to pycodestyle
- delete shebang from pycodestyle.py
- update to version 2.3.1
  * renamed from pep8 to pycodestyle
  * removed use of project-level .pep8 config file
  * updated code style, added new warnings
* Mon Aug 15 2016 toddrme2178@gmail.com
- Fix update-alternatives implementation.
* Wed Jan 13 2016 toddrme2178@gmail.com
- Implement update-alternatives
* Wed Jan 13 2016 toddrme2178@gmail.com
- Update to 1.7.0
  + Announcements:
  * Repository moved to PyCQA Organization on GitHub:
    https://github.com/pycqa/pep8
  + Changes:
  * Reverted the fix in #368, "options passed on command line are only ones
    accepted" feature. This has many unintended consequences in pep8 and flake8
    and needs to be reworked when I have more time.
  * Added support for Python 3.5. (Issue #420 & #459)
  * Added support for multi-line config_file option parsing. (Issue #429)
  * Improved parameter parsing. (Issues #420 & #456)
  + Bugs:
  * Fixed BytesWarning on Python 3. (Issue #459)
* Tue Feb 17 2015 mcihar@suse.cz
- Update to 1.6.2:
  * Added check for breaking around a binary operator. (Issue #197, Pull #305)
  * Assign variables before referenced. (Issue #287)
  * Report E731 for lambda assignment. (Issue #277)
  * Report E704 for one-liner def instead of E701. Do not report this error in the default configuration. (Issue #277)
  * Replace codes E111, E112 and E113 with codes E114, E115 and E116 for bad indentation of comments. (Issue #274)
  * Report E266 instead of E265 when the block comment starts with multiple #. (Issue #270)
  * Report E402 for import statements not at the top of the file. (Issue #264)
  * Do not enforce whitespaces around ** operator. (Issue #292)
  * Strip whitespace from around paths during normalization. (Issue #339 / #343)
  * Update --format documentation. (Issue #198 / Pull Request #310)
  * Add .tox/ to default excludes. (Issue #335)
  * Do not report E121 or E126 in the default configuration. (Issues #256 / #316)
  * Allow spaces around the equals sign in an annotated function. (Issue #357)
  * Allow trailing backslash if in an inline comment. (Issue #374)
  * If --config is used, only that configuration is processed. Otherwise, merge the user and local configurations are merged. (Issue #368 / #369)
* Tue Jan 20 2015 dap.darkness@gmail.com
- Added "Requires: python-setuptools" to prevent
  "ImportError: No module named pkg_resources" if executed.
* Fri Jun 27 2014 dmueller@suse.com
- update to 1.5.7:
  * Skip the traceback on "Broken pipe" signal. (Issue #275)
  * Do not exit when an option in ``setup.cfg`` or ``tox.ini``
    is not recognized.
  * Check the last line even if it does not end with a newline. (Issue #286)
  * Always open files in universal newlines mode in Python 2. (Issue #288)
* Fri May  9 2014 toddrme2178@gmail.com
- update to 1.5.6:
  * Check the last line even if it has no end-of-line.
- update to 1.5.5:
  * Fix regression with E22 checks and inline comments.
* Mon Apr 14 2014 dmueller@suse.com
- update to 1.5.4:
  * Fix negative offset with E303 before a multi-line docstring.
  * Fix wrong offset computation when error is on the last char
    of a physical line. (Issue #268)
  * Distribute a universal wheel file.
  * Report correct line number for E303 with comments. (Issue #60)
  * Do not allow newline after parameter equal. (Issue #252)
  * Fix line number reported for multi-line strings. (Issue #220)
  * Fix false positive E121/E126 with multi-line strings. (Issue #265)
  * Fix E501 not detected in comments with Python 2.5.
  * Fix caret position with ``--show-source`` when line contains tabs.
  * Fix a crash with E125 on multi-line strings. (Issue #263)
  * Report E129 instead of E125 for visually indented line with same
    indent as next logical line.  (Issue #126)
  * Report E265 for space before block comment. (Issue #190)
  * Allow long lines in multiline strings and comments if they cannot
    be wrapped. (Issue #224).
  * Optionally disable physical line checks inside multiline strings,
    using ``# noqa``. (Issue #242)
  * Change text for E121 to report "continuation line under-indented
    for hanging indent" instead of indentation not being a
    multiple of 4.
  * Report E131 instead of E121 / E126 if the hanging indent is not
    consistent within the same continuation block.  It helps when
    error E121 or E126 is in the ``ignore`` list.
  * Report E126 instead of E121 when the continuation line is hanging
    with extra indentation, even if indentation is not a multiple of 4.
  * Allow the checkers to report errors on empty files. (Issue #240)
  * Fix ignoring too many checks when ``--select`` is used with codes
    declared in a flake8 extension. (Issue #216)
  * Fix regression with multiple brackets. (Issue #214)
  * Fix ``StyleGuide`` to parse the local configuration if the
    keyword argument ``paths`` is specified. (Issue #246)
  * Fix a false positive E124 for hanging indent. (Issue #254)
  * Fix a false positive E126 with embedded colon. (Issue #144)
  * Fix a false positive E126 when indenting with tabs. (Issue #204)
  * Fix behaviour when ``exclude`` is in the configuration file and
    the current directory is not the project directory. (Issue #247)
  * The logical checks can return ``None`` instead of an empty iterator.
    (Issue #250)
  * Do not report multiple E101 if only the first indentation starts
    with a tab. (Issue #237)
  * Fix a rare false positive W602. (Issue #34)
- remove no-tox-test.diff
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri Oct 18 2013 dmueller@suse.com
- add 0001-reverted-fix-for-issue-204-added-check-for-214.patch:
  * Add fix for regression in 1.4.6
* Tue Oct 15 2013 toddrme2178@gmail.com
- Upodate to version 1.4.6
  * Honor ``# noqa`` for errors E711 and E712. (Issue #180)
  * When both a ``tox.ini`` and a ``setup.cfg`` are present in the project
    directory, merge their contents.  The ``tox.ini`` file takes
    precedence (same as before). (Issue #182)
  * Give priority to ``--select`` over ``--ignore``. (Issue #188)
  * Compare full path when excluding a file. (Issue #186)
  * Correctly report other E12 errors when E123 is ignored. (Issue #103)
  * New option ``--hang-closing`` to switch to the alternative style of
    closing bracket indentation for hanging indent.  Add error E133 for
    closing bracket which is missing indentation. (Issue #103)
  * Accept both styles of closing bracket indentation for hanging indent.
    Do not report error E123 in the default configuration. (Issue #103)
  * Do not crash when running AST checks and the document contains null bytes.
    (Issue #184)
  * Fix false positive E261/E262 when the file contains a BOM. (Issue #193)
  * Fix E701, E702 and E703 not detected sometimes. (Issue #196)
  * Fix E122 not detected in some cases. (Issue #201 and #208)
  * Fix false positive E121 with multiple brackets. (Issue #203)
* Tue May 28 2013 speilicke@suse.com
- Drop old tarball
- Document no-tox-test.diff
* Sat May 18 2013 dmueller@suse.com
- udpate to 1.4.5:
  * When no path is specified, do not try to read from stdin.
  * Do not require ``setuptools`` in setup.py.  It works around an issue
  with ``pip`` and Python 3. (Issue #172)
  * Add ``__pycache__`` to the ignore list.
  * Change misleading message for E251. (Issue #171)
  * Do not report false E302 when the source file has a coding cookie or a
  comment on the first line. (Issue #174)
  * Reorganize the tests and add tests for the API and for the command line
  usage and options. (Issues #161 and #162)
  * Ignore all checks which are not explicitly selected when ``select`` is
  passed to the ``StyleGuide`` constructor
* Sun Feb 24 2013 p.drouand@gmail.com
- Update to version 1.4.4:
  * Report E227 or E228 instead of E225 for whitespace around bitwise,
    shift or modulo operators. (Issue #166)
  * Change the message for E226 to make clear that it is about arithmetic operators.
  * Fix a false positive E128 for continuation line indentation with tabs.
  * Fix regression with the --diff option. (Issue #169)
  * Fix the TestReport class to print the unexpected warnings and errors.
* Fri Feb 22 2013 p.drouand@gmail.com
- Update to version 1.4.3:
  * Hide the --doctest and --testsuite options when installed.
  * Fix crash with AST checkers when the syntax is invalid. (Issue #160)
  * Read from standard input if no path is specified.
  * Initiate a graceful shutdown on Control+C.
  * Allow to change the checker_class for the StyleGuide.
* Mon Jan 28 2013 dmueller@suse.com
- Update to version 1.4.1:
  * Report E703 instead of E702 for the trailing semicolon. (Issue #117)
  * Report E226 instead of E225 for optional white space around common
  operators (``*``, ``**``, ``/``, ``+`` and ``-``).  This new error
  code is ignored in the default configuration because PEP 8 recommends
  to "use your own judgement". (Issue #96)
  * Lines with a ``# nopep8`` at the end will not issue errors on line
  length E501 or continuation line indentation E12*. (Issue #27)
  * Fix AssertionError when the source file contains an invalid line
  ending ``"\r\r\n"``. (Issue #119)
  * Read the ``[pep8]`` section of ``tox.ini`` or ``setup.cfg`` if present.
  * Add the Sphinx-based documentation, and publish it
  * Fix false positive E124 and E128 with comments. (Issue #100)
  * Fix error on stdin when running with bpython. (Issue #101)
  * Fix false positive E401. (Issue #104)
  * Report E231 for nested dictionary in list. (Issue #142)
  * Catch E271 at the beginning of the line. (Issue #133)
  * Fix false positive E126 for multi-line comments. (Issue #138)
  * Fix false positive E221 when operator is preceded by a comma. (Issue #135)
  * Fix ``--diff`` failing on one-line hunk. (Issue #137)
  * Fix the ``--exclude`` switch for directory paths. (Issue #111)
  * Use ``-`` filename to read from standard input. (Issue #128)
  * Fix regression with continuation line checker. (Issue #98)
  * Add E902 for IO errors. (Issue #87)
  * Fix false positive for E121, and missed E124. (Issue #92)
  * Allow ``verbose`` in the configuration file. (Issue #91)
  * Show the enforced ``max-line-length`` in the error message. (Issue #86)
* Tue Jun 26 2012 saschpe@suse.de
- Update to version 1.3.1:
  + Explain which configuration options are expected. Accept and recommend
    the options names with hyphen instead of underscore. (Issue #82)
  + Do not read the user configuration when used as a module (except if
    config_file=True is passed to the StyleGuide constructor).
  + Fix wrong or missing cases for the E12 series.
  + Fix cases where E122 was missed. (Issue #81)
- Changes from version 1.3.0:
  + Remove global configuration and refactor the library around a StyleGuide
    class; add the ability to configure various reporters. (Issue #35 and #66)
  + Read user configuration from ~/.config/pep8 and local configuration from
    ./.pep8. (Issue #22)
  + Fix E502 for backslash embedded in multi-line string. (Issue #68)
  + Fix E225 for Python 3 iterable unpacking (PEP 3132). (Issue #72)
  + Enable the new checkers from the E12 series in the default configuration.
  + Suggest less error-prone alternatives for E712 errors.
  + Rewrite checkers to run faster (E22, E251, E27).
  + Fixed a crash when parsed code is invalid (too many closing brackets).
  + Fix E127 and E128 for continuation line indentation. (Issue #74)
  + New option --format to customize the error format. (Issue #23)
  + New option --diff to check only modified code. The unified diff is read
    from STDIN. Example: hg diff | pep8 --diff (Issue #39)
  + Correctly report the count of failures and set the exit code to 1 when
    the --doctest or the --testsuite fails.
  + Correctly detect the encoding in Python 3. (Issue #69)
  + Drop support for Python 2.3, 2.4 and 3.0. (Issue #78)
- Don't package empty TODO.txt
* Wed Jun  6 2012 saschpe@suse.de
- Update to version 1.2:
  * Add E121 through E128 for continuation line indentation.  These
    checks are disabled by default.  If you want to force all checks,
    use switch ``--select=E,W``.  Patch by Sam Vilain. (Issue #64)
  * Add E721 for direct type comparisons. (Issue #47)
  * Add E711 and E712 for comparisons to singletons. (Issue #46)
  * Fix spurious E225 and E701 for function annotations. (Issue #29)
  * Add E502 for explicit line join between brackets.
  * Fix E901 when printing source with ``--show-source``.
  * Report all errors for each checker, instead of reporting only the
    first occurence for each line.
  * Option ``--show-pep8`` implies ``--first``.
* Wed May 23 2012 toddrme2178@gmail.com
- Add python 3 package
- Clean up spec file
- Update to release 1.1
  * Add E901 for syntax errors. (Issues #63 and #30)
  * Add E271, E272, E273 and E274 for extraneous whitespace around
    keywords. (Issue #57)
  * Add ``tox.ini`` configuration file for tests. (Issue #61)
  * Add ``.travis.yml`` configuration file for continuous integration.
    (Issue #62)
* Fri Apr 13 2012 toganm@opensuse.org
- Update to release 1.0.1 For more details regarding changes since
  release 0.6.1 please consult CHANGES.txt
  * Fix inconsistent version numbers.
* Thu Sep 22 2011 saschpe@suse.de
- Remove %%clean section
- Require python-distribute instead of python-setuptools
* Fri Sep  9 2011 alexandre@exatati.com.br
- Add Requires on python-setuptools.
* Fri Jul  8 2011 saschpe@suse.de
- Removed some unneeded macros
* Fri May  6 2011 saschpe@suse.de
- Initial package (version 0.6.1)
